==> viha-5.15.tar.gz: viha-5.15/ryhma-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma";
$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Ryhm</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", ryhmtietojen pivitys</h1>
";

taktiset_linkit();

echo "<form action=\"\" method=\"GET\">\n";

echo "<p>Oletusverkko: " . ota_oletus_verkko() . "\n";

$sql_tail =
  "FROM $table, ryhma_tila, paikka, verkko
   WHERE ryhma_tila.id = ryhma_tila_id AND paikka.id = paikka_id
         AND verkko.id = verkko_id
         AND (ryhma.paivystys_id = " . s("paivystys") . "
              OR (ryhma.alue_id = " . s("alue") . "
                  AND ryhma.paivystys_id = 2)
              OR ryhma.alue_id = 2)
   ORDER BY pri";
$columns = 3;
$items = ota_yksi("SELECT COUNT(*) $sql_tail");
$percol = intval(floor(($items + $columns - 1) / $columns));
$sql =
  "SELECT ryhma.id, kutsu, ryhma_tila, paikka, koordinaatit, verkko
   $sql_tail";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "  <td>
  <table border=1>" . tr_bgcolor()
	. "<th>Ryhm [V]<th>Tila<th>Sijainti [K]\n";
    }
    echo "    <tr>",
      "<TD>$a[kutsu]"
      . muotoile_verkko($a['verkko'], $a['id']),
      "<td><a href=\"ryhma-takt-1.php?id=$a[id]\">$a[ryhma_tila]</a>",
      "<td>$a[paikka]", muotoile_koordinaatit($a['koordinaatit']), "\n";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "
  </table>\n
  </td>\n";
    }
    $n ++;
  }
  echo "
</tr>\n
</TABLE>\n";
} else {
    echo "<P>Plop. Ei henkiltietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma-takt.php,v 1.7 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/ryhma-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma";
$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Ryhm</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", ryhmtietojen pivitys</h1>
";

taktiset_linkit();

echo "<form action=\"\" method=\"GET\">\n";

echo "<p>Oletusverkko: " . ota_oletus_verkko() . "\n";

$sql_tail =
  "FROM $table, ryhma_tila, paikka, verkko
   WHERE ryhma_tila.id = ryhma_tila_id AND paikka.id = paikka_id
         AND verkko.id = verkko_id
         AND (ryhma.paivystys_id = " . s("paivystys") . "
              OR (ryhma.alue_id = " . s("alue") . "
                  AND ryhma.paivystys_id = 2)
              OR ryhma.alue_id = 2)
   ORDER BY pri";
$columns = 3;
$items = ota_yksi("SELECT COUNT(*) $sql_tail");
$percol = intval(floor(($items + $columns - 1) / $columns));
$sql =
  "SELECT ryhma.id, kutsu, ryhma_tila, paikka, koordinaatit, verkko
   $sql_tail";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "  <td>
  <table border=1>" . tr_vaalsin()
	. "<th>Ryhm [V]<th>Tila<th>Sijainti [K]\n";
    }
    echo "    <tr>",
      "<TD>$a[kutsu]"
      . muotoile_verkko($a['verkko'], $a['id']),
      "<td><a href=\"ryhma-takt-1.php?id=$a[id]\">$a[ryhma_tila]</a>",
      "<td>$a[paikka]", muotoile_koordinaatit($a['koordinaatit']), "\n";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "
  </table>\n
  </td>\n";
    }
    $n ++;
  }
  echo "
</tr>\n
</TABLE>\n";
} else {
    echo "<P>Plop. Ei henkiltietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma-takt.php,v 1.9 2009/09/29 16:09:15 riku Exp $ -->
